/****************************************************************************
** Meta object code from reading C++ file 'qvirtualkeyboardfeatures_namespace_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtvirtualkeyboard/src/virtualkeyboard/qvirtualkeyboardfeatures_namespace_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvirtualkeyboardfeatures_namespace_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QVirtualKeyboardFeaturesE_t {};
} // unnamed namespace

template <> constexpr inline auto QVirtualKeyboardFeatures::qt_create_metaobjectdata<qt_meta_tag_ZN24QVirtualKeyboardFeaturesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QVirtualKeyboardFeatures",
        "QML.Element",
        "VirtualKeyboardFeatures",
        "QML.AddedInVersion",
        "1540",
        "Feature",
        "Handwriting"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Feature'
        QtMocHelpers::EnumData<Feature>(5, 5, QMC::EnumFlags{}).add({
            {    6, Feature::Handwriting },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN24QVirtualKeyboardFeaturesE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN24QVirtualKeyboardFeaturesE =
    QVirtualKeyboardFeatures::qt_create_metaobjectdata<qt_meta_tag_ZN24QVirtualKeyboardFeaturesE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN24QVirtualKeyboardFeaturesE =
    qt_staticMetaObjectContent_ZN24QVirtualKeyboardFeaturesE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN24QVirtualKeyboardFeaturesE =
    qt_staticMetaObjectContent_ZN24QVirtualKeyboardFeaturesE.relocatingData;

Q_CONSTINIT const QMetaObject QVirtualKeyboardFeatures::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN24QVirtualKeyboardFeaturesE.stringdata,
    qt_staticMetaObjectStaticContent_ZN24QVirtualKeyboardFeaturesE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN24QVirtualKeyboardFeaturesE.metaTypes,
    nullptr
} };

QT_WARNING_POP
