/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<hangulinputmethod.h>)
#  include <hangulinputmethod.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick_VirtualKeyboard_Plugins_Hangul()
{
    qmlRegisterModule("QtQuick.VirtualKeyboard.Plugins.Hangul", 2, 0);
    qmlRegisterModule("QtQuick.VirtualKeyboard.Plugins.Hangul", 2, 254);
    qmlRegisterModule("QtQuick.VirtualKeyboard.Plugins.Hangul", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QtVirtualKeyboard::HangulInputMethod>("QtQuick.VirtualKeyboard.Plugins.Hangul", 6);
    qmlRegisterAnonymousTypesAndRevisions<QVirtualKeyboardAbstractInputMethod>("QtQuick.VirtualKeyboard.Plugins.Hangul", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtQuick.VirtualKeyboard.Plugins.Hangul", 6, 11);
}

static const QQmlModuleRegistration qtQuickVirtualKeyboardPluginsHangulRegistration("QtQuick.VirtualKeyboard.Plugins.Hangul", qml_register_types_QtQuick_VirtualKeyboard_Plugins_Hangul);
